pub struct HeaderlineRow {
pub cells: Arc<[Cell]>,
pub bg: Option<u32>,
}Expand description
The row produced by a Headerline impl when it wants to be visible.
Fields
cells: Arc<[Cell]>Cells to paint. Non-empty (callers return None when the row should
be hidden instead of returning an empty cell slice).
bg: Option<u32>Override the renderer’s sticky-row background. None → renderer uses
the theme-defined header background. Some(0xRRGGBB) → hard-coded
colour (e.g. tutor’s retro palette).